@@ -12,6 +12,8 @@ fn tohtml(buffer: String) -> PyResult<String>  {
     // and we therefore must enable it explicitly.
     let mut options = Options::empty();
     options.insert(Options::ENABLE_STRIKETHROUGH);
+    options.insert(Options::ENABLE_TABLES);
+    options.insert(Options::ENABLE_TASKLISTS);
     let parser = Parser::new_ext(&buffer, options);
 
     // Write to String buffer.
@@ -21,18 +23,6 @@ fn tohtml(buffer: String) -> PyResult<String>  {
     Ok(html_output)
 }
 
-
-/// Formats the sum of two numbers as string.
-#[pyfunction]
-fn sum_as_string(a: usize, b: usize) -> PyResult<String> {
-    Ok((a + b).to_string())
-}
-
-#[pyfunction]
-fn multiplication_as_string(a: usize, b: usize) -> PyResult<String> {
-    Ok((a * b).to_string())
-}
-
 /// A Python module implemented in Rust.
 #[pymodule]
 fn fastmd(_py: Python, m: &PyModule) -> PyResult<()> {
